pygeai.assistant package
========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pygeai.assistant.data
   pygeai.assistant.data_analyst
   pygeai.assistant.rag

Submodules
----------

pygeai.assistant.clients module
-------------------------------

.. automodule:: pygeai.assistant.clients
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.assistant.endpoints module
---------------------------------

.. automodule:: pygeai.assistant.endpoints
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.assistant.managers module
--------------------------------

.. automodule:: pygeai.assistant.managers
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.assistant.mappers module
-------------------------------

.. automodule:: pygeai.assistant.mappers
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: pygeai.assistant
   :members:
   :show-inheritance:
   :undoc-members:
